Octopus Sensing Visualizer
==========================

Octopus Sensing Visualizer is a web-based real-time visualizer for `Octopus Sensing <https://octopus-sensing.nastaran-saffar.me/>`_. 
It can be used for offline data visualization. You can visualize the recorded multimodal data as the raw data. Also, it can extract
some essential features or components of data and display them in a single window. Using this tool, you can observe the effect of an event on recorded data simultaneously.

`Octopus Sensing Visualizer <https://github.com/octopus-sensing/octopus-sensing-visualizer>`_ is 
a separated project and can be installed if we need to visualize data. 
It can be used for displaying recorded data with
the same format as we recorded through Octopus Sensing.

**To see the full documentation go to [Otopus Sensing](https://octopus-sensing.nastaran-saffar.me/visualizer) website.**

Copyright
---------

Copyright © 2021 [Nastaran Saffaryazdi]

This program is free software: you can redistribute it and/or modify it under the terms of the GNU
General Public License as published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

See `License file <https://github.com/nastaran62/octopus-sensing/blob/master/LICENSE>`_  for full terms.